| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Update.Nix.FetchGit
- updatesFromFile :: FilePath -> IO (Either Warning [SpanUpdate])
Documentation
updatesFromFile :: FilePath -> IO (Either Warning [SpanUpdate]) Source #
Given the path to a Nix file, returns the SpanUpdates all the parts of the file we want to update.